<?
session_start(); // session Ѵ.
include_once "../include/print.php";
parse_query_str();
if ($mode == "login") {
  session_register("mysqlpass"); // Ѵ.
  header("Location: install.php?langss=$langss");
} elseif ($mode == "logout") {
  session_destroy(); //  Ѵ
  header("Location: auth.php?mode=first&langss=$langss");
} elseif ($mode == "first") {
  session_destroy(); //  Ѵ
  $langs['code'] = ($langss == "ko") ? "ko" : "en";

  $path['type'] = "Install";
  include "../include/lang.php";
  $str = str_replace("\n","\\n",$langs['first_acc']);
  $nostr = str_replace("\n","<BR>\n",$str);
  echo "<script>\n" .
       "  alert('$str')\n" .
       "  document.location='../login.php?type=admin'\n" .
       "</script>\n".
       "<NOSCRIPT>\n".
       "Message: $nostr<BR>\n".
       "And If you want to go main administrator's page, <A HREF=../login.php?type=admin>click here</A>!\n".
       "</NOSCRIPT>\n";
  exit;
}
?>
